From: Johannes Sixt Date: Thu, 09 Jun 2016 21:10:09 GMT Subject: Re: [PATCH v2 00/94] libify apply and use lib in am Message-ID: <5759DB31.2000106@kdbg.org> In-Reply-To: Am 12.05.2016 um 20:02 schrieb Christian Couder: > On Thu, May 12, 2016 at 7:06 PM, Johannes Sixt wrote: >> Am 11.05.2016 um 15:16 schrieb Christian Couder: >>> >>> This is a patch series about libifying `git apply` functionality, and >>> using this libified functionality in `git am`, so that no 'git apply' >>> process is spawn anymore. This makes `git am` significantly faster, so >>> `git rebase`, when it uses the am backend, is also significantly >>> faster. >> >> >> I'm including this in my build on Windows. It passes the test suite. > > Great! Thanks for the report! > >> I'll also use it in production for a while, although I am not a git-am >> consumer nor do I use git-rebase without -i, hence, my tests will probably >> only show that there is no bad fall-out. Meanwhile, I have retrained my muscle memory to stop before typing "-i" after "rebase" for an opportunity to consider whether bare rebase can be used. What should I say? I am impressed. It's like 100 times faster than rebase -i (on Windows). I'm now using it whenever I can, and more often than not I plan my rebase workflow so that I can go ahead without -i. Can't wait to test a re-roll on top of cc/apply-introduce-state! -- Hannes